"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getClosestMatchingVersion = void 0;
var semver_1 = require("semver");
/**
 * Gets the closest matching package version info.
 *
 * @param availableVersions
 * @param version
 */
function getClosestMatchingVersion(availableVersions, version) {
    var parsedVersion = parseOrThrow(version);
    return (availableVersions.find(function (v) {
        var parsedAvailableVersion = parseOrThrow(v.version);
        if (parsedVersion.major !== parsedAvailableVersion.major) {
            return false;
        }
        if (parsedVersion.minor !== parsedAvailableVersion.minor) {
            return false;
        }
        return true;
    }) || availableVersions[0]);
}
exports.getClosestMatchingVersion = getClosestMatchingVersion;
/**
 * Parses the version or throws an error.
 *
 * @param version
 * @returns
 */
function parseOrThrow(version) {
    var parsed = (0, semver_1.parse)(cleanVersion(version));
    if (!parsed) {
        throw new Error("Could not parse version '".concat(version, "'"));
    }
    return parsed;
}
/**
 * Cleans the version of any semver range specifiers.
 * @param version
 * @returns
 */
function cleanVersion(version) {
    return version.replace(/^[\^~=\s]/, '');
}
//# sourceMappingURL=versioning.js.map